@@ -126,10 +126,16 @@ addPgEvent <- function(db, UIDs=NULL, binary, eventType, comment = NA,
             # binDf$millis <- paste0(sapply(nchar(binDf$millis), function(x) {
             #     paste0(rep('0', max(3-x, 0), collapse=''))
             # }), binDf$millis)
-            binDf$dbDate <- paste0(format(convertPgDate(binDf$date), format='%Y-%m-%d %H:%M:%S'), '.',
-                                   paste0(sapply(nchar(binDf$millis), function(x) {
-                                       paste0(rep('0', max(3-x, 0), collapse=''))
-                                   }), binDf$millis))
+            milliChar <- sprintf('%.3f', binDf$millis / 1e3)
+            milliChar <- gsub('^0', '', milliChar)
+            # binDf$dbDate <- paste0(format(convertPgDate(binDf$date), format='%Y-%m-%d %H:%M:%S'), '.',
+            #                        paste0(sapply(nchar(binDf$millis), function(x) {
+            #                            paste0('', rep('0', max(3-x, 0), collapse=''))
+            #                        }), binDf$millis))
+            binDf$dbDate <- paste0(
+                format(convertPgDate(binDf$date), format='%Y-%m-%d %H:%M:%S'),
+                milliChar
+            )
             clickAppend <- clickData[FALSE, ]
             clickAppend[1:nrow(binDf), ] <- NA
             clickAppend$UTC <- binDf$dbDate
