@@ -165,8 +165,10 @@ setMethod('matchEnvData', 'data.frame',
                       planFiles[[p]] <- downloadEnv(data=data[plan == p, ],fileName = thisFile, edinfo = nc, buffer = buffer, ...)
                       #####################################
                       on.exit({
-                          tmpFiles <- list.files(getTempCacheDir(), full.names=TRUE)
-                          unlink(tmpFiles, force=TRUE)
+                          # tmpFiles <- list.files(getTempCacheDir(), full.names=TRUE)
+                          # unlink(tmpFiles, force=TRUE)
+                          tempDir <- getTempCacheDir()
+                          unlink(tempDir, recursive=TRUE, force=TRUE)
                       })
                       # on.exit(DELETEYOUR PAMMISC TEMP DIR HERE) cache_delete_all from rerddap checkit
                       ######################################
@@ -175,13 +177,23 @@ setMethod('matchEnvData', 'data.frame',
                           setTxtProgressBar(pb, value = pbix)
                       }
                   }
-                  result <- vector('list', length = nrow(data))
+                  # result <- vector('list', length = nrow(data))
+                  # for(i in seq_along(result)) {
+                  #     if(plan[i] == '-1') {
+                  #         result[[i]] <- data[i, ]
+                  #         next
+                  #     }
+                  #     result[[i]] <- ncToData(data=data[i, ], nc=planFiles[[plan[i]]], var=var, buffer=buffer, FUN=FUN, progress=FALSE, depth=depth, ...)
+                  # }
+                  data <- split(data, plan)
+                  result <- vector('list', length=length(data))
                   for(i in seq_along(result)) {
-                      if(plan[i] == '-1') {
-                          result[[i]] <- data[i, ]
+                      if(names(data)[i] == '-1') {
+                          result[[i]] <- data[[i]]
                           next
                       }
-                      result[[i]] <- ncToData(data=data[i, ], nc=planFiles[[plan[i]]], var=var, buffer=buffer, FUN=FUN, progress=FALSE, depth=depth, ...)
+                      result[[i]] <- ncToData(data=data[[i]], nc=planFiles[[names(data)[i]]], var=var, buffer=buffer,
+                                                        FUN=FUN, progress=FALSE, depth=depth, ...)
                   }
                   if(progress) {
                       cat('\n')
